import { createComponent, mergeProps, use, effect, style, className, template } from 'solid-js/web';
import * as echarts from 'echarts';
import { onMount, onCleanup, createEffect } from 'solid-js';
import { createResizeObserver } from '@solid-primitives/resize-observer';
import { debounce } from '@solid-primitives/scheduled';

// src/index.tsx

// src/utils.ts
var typeIsString = (value) => typeof value === "string" || value instanceof String;
var typeIsFunction = (value) => typeof value === "function";

// src/EChartsCore.tsx
var _tmpl$ = /* @__PURE__ */ template(`<div>`);
var SolidEChartsCore = (props) => {
  let echartsRef;
  let chartRef;
  let isFirstResize = true;
  onMount(() => {
    chartRef = props.echarts.init(echartsRef, props.theme, props.opts);
    bindEvents(chartRef, props.createEvents ?? {});
    createResizeObserver(echartsRef, (_, el) => {
      if (el === echartsRef)
        resizeChart();
    });
  });
  onCleanup(() => {
    disposeChart();
  });
  createEffect(() => {
    const instance = getEchartsInstance();
    instance?.setOption(props.option, props.notMerge, props.lazyUpdate);
    if (props.showLoading) {
      instance?.showLoading(props.loadingOption);
    } else {
      instance?.hideLoading();
    }
  });
  const resizeChart = debounce(() => {
    const instance = getEchartsInstance();
    if (!isFirstResize && instance) {
      try {
        instance.resize({
          width: "auto",
          height: "auto"
        });
      } catch (e) {
        console.warn(e);
      }
    }
    isFirstResize = false;
  }, props.debouncedResize ? 250 : 0);
  const disposeChart = () => {
    if (echartsRef) {
      props.echarts.dispose(echartsRef);
    }
  };
  const getEchartsInstance = () => {
    if (echartsRef) {
      return props.echarts.getInstanceByDom(echartsRef);
    }
    return void 0;
  };
  const bindEvents = (instance, events) => {
    for (const [eventType, eventCallback] of Object.entries(events ?? {})) {
      if (typeIsString(eventType) && typeIsFunction(eventCallback)) {
        instance.on(eventType, (parameters) => {
          eventCallback(parameters, instance);
        });
      } else {
        console.warn("The event passed in must be a string, and the callback must be a function.", eventType, eventCallback);
      }
    }
  };
  const style$1 = {
    height: "400px",
    width: "100%",
    ...props.style
  };
  return (() => {
    const _el$ = _tmpl$();
    const _ref$ = echartsRef;
    typeof _ref$ === "function" ? use(_ref$, _el$) : echartsRef = _el$;
    effect((_p$) => {
      const _v$ = style$1, _v$2 = props.class;
      _p$._v$ = style(_el$, _v$, _p$._v$);
      _v$2 !== _p$._v$2 && className(_el$, _p$._v$2 = _v$2);
      return _p$;
    }, {
      _v$: void 0,
      _v$2: void 0
    });
    return _el$;
  })();
};
var EChartsCore_default = SolidEChartsCore;

// src/index.tsx
var SolidECharts = (props) => {
  return createComponent(EChartsCore_default, mergeProps(props, {
    echarts
  }));
};

export { EChartsCore_default as SolidEChartsCore, SolidECharts as default };
