'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var web = require('solid-js/web');
var echarts = require('echarts');
var solidJs = require('solid-js');
var resizeObserver = require('@solid-primitives/resize-observer');
var scheduled = require('@solid-primitives/scheduled');

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n.default = e;
  return Object.freeze(n);
}

var echarts__namespace = /*#__PURE__*/_interopNamespace(echarts);

// src/index.tsx

// src/utils.ts
var typeIsString = (value) => typeof value === "string" || value instanceof String;
var typeIsFunction = (value) => typeof value === "function";

// src/EChartsCore.tsx
var _tmpl$ = /* @__PURE__ */ web.template(`<div>`);
var SolidEChartsCore = (props) => {
  let echartsRef;
  let chartRef;
  let isFirstResize = true;
  solidJs.onMount(() => {
    chartRef = props.echarts.init(echartsRef, props.theme, props.opts);
    bindEvents(chartRef, props.createEvents ?? {});
    resizeObserver.createResizeObserver(echartsRef, (_, el) => {
      if (el === echartsRef)
        resizeChart();
    });
  });
  solidJs.onCleanup(() => {
    disposeChart();
  });
  solidJs.createEffect(() => {
    const instance = getEchartsInstance();
    instance?.setOption(props.option, props.notMerge, props.lazyUpdate);
    if (props.showLoading) {
      instance?.showLoading(props.loadingOption);
    } else {
      instance?.hideLoading();
    }
  });
  const resizeChart = scheduled.debounce(() => {
    const instance = getEchartsInstance();
    if (!isFirstResize && instance) {
      try {
        instance.resize({
          width: "auto",
          height: "auto"
        });
      } catch (e) {
      }
    }
    isFirstResize = false;
  }, props.debouncedResize ? 250 : 0);
  const disposeChart = () => {
    if (echartsRef) {
      props.echarts.dispose(echartsRef);
    }
  };
  const getEchartsInstance = () => {
    if (echartsRef) {
      return props.echarts.getInstanceByDom(echartsRef);
    }
    return void 0;
  };
  const bindEvents = (instance, events) => {
    for (const [eventType, eventCallback] of Object.entries(events ?? {})) {
      if (typeIsString(eventType) && typeIsFunction(eventCallback)) {
        instance.on(eventType, (parameters) => {
          eventCallback(parameters, instance);
        });
      }
    }
  };
  const style = {
    height: "400px",
    width: "100%",
    ...props.style
  };
  return (() => {
    const _el$ = _tmpl$();
    const _ref$ = echartsRef;
    typeof _ref$ === "function" ? web.use(_ref$, _el$) : echartsRef = _el$;
    web.effect((_p$) => {
      const _v$ = style, _v$2 = props.class;
      _p$._v$ = web.style(_el$, _v$, _p$._v$);
      _v$2 !== _p$._v$2 && web.className(_el$, _p$._v$2 = _v$2);
      return _p$;
    }, {
      _v$: void 0,
      _v$2: void 0
    });
    return _el$;
  })();
};
exports.SolidEChartsCore = SolidEChartsCore;

// src/index.tsx
exports.default = (props) => {
  return web.createComponent(exports.SolidEChartsCore, web.mergeProps(props, {
    echarts: echarts__namespace
  }));
};
